Canonical immutable runtime robot model and strict robot.json encoding.
Re-exports
pub use asset::AssetId;pub use robot::ROBOT_SCHEMA;pub use robot::Robot;pub use robot::RobotIdentity;
Modules
- asset
- Canonical logical asset identities.
- component
- Canonical component facts used after authored documents are loaded.
- robot
- Canonical immutable robot model.
- simulation
- Canonical simulation facts used after authored documents are loaded.
- structure
- Canonical normalized structure facts.
Structs
- Encode
Error - Canonical encoding failure.
Enums
- Decode
Error - Canonical decoding failure.
- Model
Error - Invalid canonical robot semantics.