Inertia

Struct Inertia 

pub struct Inertia {
    pub ixx: f64,
    pub ixy: f64,
    pub ixz: f64,
    pub iyy: f64,
    pub iyz: f64,
    pub izz: f64,
}
The symmetric inertia tensor of one link, in kg*m^2.

The default is the unit tensor. The tensor must describe a physically realizable body, which RobotBuilder::build checks.

Fields

ixx: f64

The moment about X.

ixy: f64

The product of inertia between X and Y.

ixz: f64

The product of inertia between X and Z.

iyy: f64

The moment about Y.

iyz: f64

The product of inertia between Y and Z.

izz: f64

The moment about Z.