pub struct Material<'a> {
pub name: &'a str,
pub color: Option<[f64; 4]>,
pub texture: Option<AssetId>,
}Expand description
How a visual is rendered.
A material is stated where it is used, and may also be added to the
structure’s own catalogue with RobotBuilder::material.
Fields
name: &'a strThe material’s name, which is how a structure refers to it.
color: Option<[f64; 4]>Linear RGBA in 0.0..=1.0, when the material states a colour.
texture: Option<AssetId>The texture image, when the material states one.
Implementations