pub struct Robot { /* private fields */ }Expand description
Fully normalized runtime-facing robot model.
Implementations
Sourceimpl Robot
impl Robot
Sourcepub fn encode(&self) -> Result<Vec<u8>, EncodeError>
pub fn encode(&self) -> Result<Vec<u8>, EncodeError>
Encode the canonical runtime wire document deterministically.
Sourcepub fn decode(bytes: &[u8]) -> Result<Self, DecodeError>
pub fn decode(bytes: &[u8]) -> Result<Self, DecodeError>
Strictly decode and validate the canonical runtime wire document.
pub fn identity(&self) -> &RobotIdentity
pub fn robot_id(&self) -> &str
pub fn namespace(&self) -> &str
pub fn motion(&self) -> &MotionModel
pub fn kinematic(&self) -> &KinematicConfig
pub const fn motion_limits(&self) -> MotionLimits
pub fn components(&self) -> impl ExactSizeIterator<Item = &ComponentInstance>
pub fn component_ids(&self) -> impl ExactSizeIterator<Item = &str>
pub fn component(&self, id: &str) -> Option<&ComponentInstance>
pub fn component_instance( &self, id: &str, ) -> Result<&ComponentInstance, ModelError>
pub fn component_for_instance(&self, id: &str) -> Result<&Component, ModelError>
pub fn simulation_for_component_type( &self, component_type: &str, ) -> Option<&Simulation>
pub fn simulation_for_instance( &self, component_id: &str, ) -> Result<Option<&Simulation>, ModelError>
pub fn structure(&self) -> &Structure
pub fn capability( &self, reference: &CapabilityRef, ) -> Result<&Capability, ModelError>
pub fn camera_capabilities(&self) -> Result<Vec<CapabilityRef>, ModelError>
pub fn require_motor( &self, reference: &CapabilityRef, ) -> Result<(&Motor, i8), ModelError>
pub fn require_encoder( &self, reference: &CapabilityRef, ) -> Result<(&Encoder, i8), ModelError>
Sourcepub fn link_target_frame(
&self,
reference: &CapabilityRef,
) -> Result<String, ModelError>
pub fn link_target_frame( &self, reference: &CapabilityRef, ) -> Result<String, ModelError>
Validate and return the namespaced runtime frame for a capability’s component-local link target.