pub struct ComponentInstance { /* private fields */ }Expand description
One resolved component instance in the canonical robot.
Implementations
Sourceimpl ComponentInstance
impl ComponentInstance
pub const fn id(&self) -> &ComponentInstanceId
pub const fn component_type(&self) -> &ComponentTypeId
Sourcepub const fn mount_link(&self) -> &LinkId
pub const fn mount_link(&self) -> &LinkId
The robot link this instance is rigidly mounted on.
Sourcepub const fn roles(&self) -> &BTreeMap<CapabilityId, BTreeSet<CapabilityRole>>
pub const fn roles(&self) -> &BTreeMap<CapabilityId, BTreeSet<CapabilityRole>>
Authored role assignments, ordered by capability and role.
Sourcepub fn has_role(&self, capability: &CapabilityId, role: CapabilityRole) -> bool
pub fn has_role(&self, capability: &CapabilityId, role: CapabilityRole) -> bool
Whether this instance assigns role to the named capability.